@@ -407,3 +407,23 @@ class PostgresqlService(MysqlService):
 
     def __close(self):
         super().close()
+
+    def drop_table(self, table):
+        try:
+            self.__connect()
+            df_tables = pd.read_sql_query("select * from pg_tables where schemaname = 'public'", con=self.conn)
+            tables = list(df_tables['tablename'])
+            if table in tables:
+                table = '\"' + table + '\"'
+                sql = 'drop table {}'.format(table)
+                cusor = self.conn.cursor()
+                cusor.execute(sql)
+                self.conn.commit()
+                cusor.close()
+                logging.debug('数据表删除成功！')
+            else:
+                logging.debug("not exists")
+        except Exception as e:
+            traceback.print_exc()
+            self.close()
+
